polimorfo package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   polimorfo.datasets
   polimorfo.utils

Submodules
----------

polimorfo.cli module
--------------------

.. automodule:: polimorfo.cli
   :members:
   :undoc-members:
   :show-inheritance:

polimorfo.polimorfo module
--------------------------

.. automodule:: polimorfo.polimorfo
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: polimorfo
   :members:
   :undoc-members:
   :show-inheritance:
